/*
 * Update the database schema
 *
 * This script must be executed on all Sitecore databases.
 */

 -- Uncomment and change the following line if you want to execute the script on a different database 
 --USE [Sitecore_Core]

if exists (select * from sys.indexes where object_id = object_id('EventQueue') and name = 'IX_Sequence')
	DROP INDEX IX_Sequence ON [EventQueue]
GO

if not exists (select * from sys.indexes where object_id = object_id('EventQueue') and name = 'IX_Stamp')
	CREATE CLUSTERED INDEX [IX_Stamp] ON [EventQueue] 
	(
		[Stamp] ASC
	) WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

if exists (select * from sys.columns where object_id = object_id('EventQueue') and name = 'Sequence')
	ALTER TABLE [EventQueue] DROP COLUMN Sequence
GO

/*
 * The rest of this script applies a number of changes to the database to make sure the database schemas
 * are consistent across all Sitecore databases in the solution. 
 * 
 * These changes were already implemented in the clean databases for 6.4 Update-1 and later. 
 */


if exists(select top 1 * from sys.columns 
where [object_id] = object_id('ArchivedItems') and name = 'Name' and collation_name = 'Danish_Norwegian_CI_AS')
	alter table ArchivedItems alter column Name nvarchar(256) not null
	
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[Descendants]') AND name = N'Ancestor')
	DROP INDEX Ancestor on Descendants

GO

if exists(select top 1 * from sys.columns 
where [object_id] = object_id('Items') and name = 'Name' and collation_name = 'Danish_Norwegian_CI_AS')
begin
	DROP INDEX ndxName on Items

	alter table Items alter column Name nvarchar(256)not null
	
	CREATE NONCLUSTERED INDEX [ndxName] ON [Items] ([Name] ASC)WITH 
		(PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
end 
	
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[SharedFields]') AND name = N'ndxItemID')
	DROP INDEX ndxItemID on SharedFields

GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[UnversionedFields]') AND name = N'ndxItemID')
	DROP INDEX ndxItemID on UnversionedFields
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[UnversionedFields]') AND name = N'ndxLookup')
	DROP INDEX ndxLookup on UnversionedFields
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[VersionedFields]') AND name = N'ndxItemID')
	DROP INDEX ndxItemID on VersionedFields
GO

IF EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[dbo].[VersionedFields]') AND name = N'ndxLookup')
	DROP INDEX ndxLookup on VersionedFields
GO

if not exists(select top 1 * from sys.columns 
where [object_id] = object_id('Tasks') and name = 'InstanceName' )
begin
	alter table Tasks add [InstanceName] [nvarchar](128) NULL
end 

go 

--Sets property ALLOW_PAGE_LOCKS = 'ON' for all indexes.
DECLARE @sExec nvarchar(max)
SELECT @sExec = 'Use [' + DB_NAME() + '];' + char(10) + 'ALTER INDEX ' + i.NAME + ' ON ' + o.NAME + ' SET ( ALLOW_PAGE_LOCKS = ON ) '
FROM sys.indexes i
INNER JOIN sys.objects o
ON i.OBJECT_ID = o.OBJECT_ID
WHERE allow_page_locks <> 1

AND i.NAME NOT IN('queue_clustered_index','queue_secondary_index')

Exec (@sExec);